@@ -18,6 +18,7 @@
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
 #else
+#include <KCrash>
 #include <QApplication>
 #endif
 
@@ -76,6 +77,10 @@ int main(int argc, char *argv[])
     about.setBugAddress("https://invent.kde.org/utilities/ktrip/-/issues");
     KAboutData::setApplicationData(about);
 
+#ifndef Q_OS_ANDROID
+    KCrash::initialize();
+#endif
+
 #ifdef Q_OS_ANDROID
     engine.rootContext()->setContextProperty(QStringLiteral("_isAndroid"), true);
     engine.rootContext()->setContextProperty(QStringLiteral("_androidUtils"), QVariant::fromValue(AndroidUtils::instance()));
